import { db } from './firebase';
import { doc, setDoc } from 'firebase/firestore';
import type { AdminUser } from '@/types/education';

const ADMIN_EMAILS = [
  'akalagborojohn@gmail.com',
  'edvolabnomvate@gmail.com'
];

export async function initializeAdminUser(uid: string, email: string): Promise<void> {
  try {
    // Only proceed if the email is in the allowed list
    if (!ADMIN_EMAILS.includes(email)) {
      throw new Error('Email not authorized for admin access');
    }

    const adminData: Omit<AdminUser, 'id'> = {
      email,
      role: 'ADMIN',
      permissions: [
        'manage_subjects',
        'manage_topics',
        'manage_questions',
        'manage_users',
        'view_analytics',
        'manage_admins'
      ],
      createdAt: new Date(),
      updatedAt: new Date(),
      isActive: true,
      lastLoginAt: new Date()
    };

    // Create or update admin user document
    await setDoc(doc(db, 'adminUsers', uid), adminData, { merge: true });
  } catch (error) {
    console.error('Error initializing admin user:', error);
    throw error;
  }
} 